arrow-cast 56.2.1

Cast kernel and utilities for Apache Arrow
docs.rs failed to build arrow-cast-56.2.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: arrow-cast-58.3.0

Functions for converting from one data type to another in Apache Arrow