Function b64_decode
Source pub fn b64_decode<E: Engine, O: OffsetSizeTrait>(
engine: &E,
array: &GenericBinaryArray<O>,
) -> Result<GenericBinaryArray<O>, ArrowError>
Base64 decode each element of array with the provided Engine
Errors
Returns an error if a value is not valid base64 for engine.