pub(crate) enum DecimalParseError {
InvalidFormat,
Overflow,
}Expand description
The reason a decimal string could not be parsed.
Variants
InvalidFormat
The input is not a valid decimal string
Overflow
The value does not fit in the precision or the native type of the decimal