enum MantissaError {
InvalidFormat,
Overflow,
Exponent(usize),
}Expand description
Why scanning the digits of a decimal string stopped.
Variants
InvalidFormat
The input is not a valid decimal string
Overflow
The value does not fit in the native type
Exponent(usize)
An exponent marker (e or E) was found at the given byte offset