fn decimal_pow<T: DecimalType>(exp: i64) -> Result<T::Native, DecimalParseError>Expand description
Returns 10^exp as a T::Native, or an overflow error if the result does
not fit in the native type.
fn decimal_pow<T: DecimalType>(exp: i64) -> Result<T::Native, DecimalParseError>Returns 10^exp as a T::Native, or an overflow error if the result does
not fit in the native type.