trim_pre_and_post_whitespace

Function trim_pre_and_post_whitespace 

fn trim_pre_and_post_whitespace(string: &str) -> &str
this is a no-op if the string starts and ends with a digit, otherwise it will trim whitespace from the start and end of the string.