pub fn single_float_to_decimal<D>(input: f64, mul: f64) -> Option<D::Native>where
D: DecimalType + ArrowPrimitiveType,
<D as ArrowPrimitiveType>::Native: DecimalCast,Expand description
Cast a single floating point value to a decimal native with the given multiple.
Returns None if the value cannot be represented with the requested precision.