struct DecimalAccumulator<T: DecimalType> {
value: T::Native,
chunk: u64,
chunk_len: usize,
negative: bool,
}Expand description
Accumulates decimal digits into chunk, folding it into value whenever
it reaches MAX_CHUNK_DIGITS digits
Fields
value: T::Nativechunk: u64chunk_len: usizenegative: boolImplementations
Sourceimpl<T: DecimalType> DecimalAccumulator<T>
impl<T: DecimalType> DecimalAccumulator<T>
fn push(&mut self, digit: u8) -> Result<(), DecimalParseError>
Sourcefn finish(self) -> Result<T::Native, DecimalParseError>
fn finish(self) -> Result<T::Native, DecimalParseError>
Folds the digits still in chunk into the value